#!/bin/ksh
# Licensed Materials - Property of IBM
# 5724-S67
# (c) Copyright IBM Corp. 1998, 2010   All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
export LC_TIME="C"

ACTUATOR_LOG=../log/$PROPSFILE.log
TEMPFILE=$TEMPFILE1
SHARED_SCRIPT=../bin/getguardium_shared.sh
ERRORFILE=$PROPSFILE.err
LOGTYPE="ACCESS"
PROPS=../run/$PROPSFILE

##################### INTERNAL FUNCTIONS #######################
function printlog {
 echo `date "+%a %D %T"` $1 >> $ACTUATOR_LOG
}

function increaseerr {
 NUM=`cat $ERRORFILE` && ((NUM += 1)) && echo $NUM > $ERRORFILE
}
##################### INTERNAL FUNCTIONS #######################

if [ "a$PROPSFILE" = "a" ] ; then 
 echo `date "+%a %D %T"` "ERROR: PROPS file is not defined. Exiting." > guardium.err
 exit 1
fi

> $ACTUATOR_LOG
> $PROPS.tmp
echo "0" > $ERRORFILE

printlog "IBM Guardium collect started on `hostname` (`uname`)."
printlog "========================================================"
printlog "Checking incoming parameters..."

# Here we will check all parameters required for collect
# This will be done only once by the first collect script
# called by guardium.cfg (getguardium_access.sh)
if [ "a$TEMPFILE1" = "a" ] ; then 
 printlog "ERROR: 1st sublog name is not defined (user access). Exiting."
 exit 1
fi
if [ "a$TEMPFILE2" = "a" ] ; then 
 printlog "ERROR: 2nd sublog name is not defined (exceptions). Exiting."
 exit 1
fi
if [ "a$TEMPFILE3" = "a" ] ; then 
 printlog "ERROR: 3rd sublog name is not defined (policy violations). Exiting."
 exit 1
fi
if [ "a$TEMPFILE4" = "a" ] ; then 
 printlog "ERROR: 4th sublog name is not defined (Guardium activity). Exiting."
 exit 1
fi
if [ "a$TEMPFILE5" = "a" ] ; then 
 printlog "ERROR: 5th sublog name is not defined (Guardium login attempts). Exiting."
 exit 1
fi
# Check log files location
if [ "a$OPTION2" = "a" ] ; then 
 printlog "ERROR: Log files location is not defined. Exiting."
 exit 1
fi
# Check log files location accesibility
if [ ! -d "$OPTION2" ] ; then
 printlog "ERROR: Log files location is not accessible. Exiting."
 exit 1
fi
# Check log template
if [ "a$OPTION3" = "a" ] ; then 
 printlog "WARNING: Access tracking log filename template is not defined. Skipping."
 increaseerr
 > $TEMPFILE
 exit 0
fi
# Check if "filemodtime" executable is available and could be executed
if [ ! -x "../bin/filemodtime" ] ; then
 printlog "ERROR: filemodtime executable is not accessible. Exiting."
 exit 1
fi
printlog "Parameters check complete."
printlog "Log files location: $OPTION2"
printlog "========================================================"

# Now we start with 1st sublog processing
printlog "Processing user access sublog (#1)"
$SHARED_SCRIPT $TEMPFILE $OPTION3 $LOGTYPE $OPTION2 $PROPSFILE

if [[ $? -eq 0 ]] ; then
 printlog "User access sublog collect: SUCCESS"
else
 printlog "ERROR: User access sublog collect: FAILURE"
 printlog "Will try to collect other sublogs."
 # We will increase number of errors every time when collect
 # failed for one of the sublogs. If number of the errors 
 # will be less then number of sublogs, we will not 
 # fail the entire collect, but just will report about 
 # the number of errors occurred.
 increaseerr
fi

printlog "========================================================"

exit 0
