#!/bin/ksh
# Licensed Materials - Property of IBM
# 5724-S67
# (c) Copyright IBM Corp. 1998, 2010   All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
export LC_TIME="C"

##################### INTERNAL FUNCTIONS #######################
function printlog {
 echo `date "+%a %D %T"` $1 >> $ACTUATOR_LOG
}

# Process Persons
function build_users {
 INPUT_FILE=$1
 USER_TYPE=$2
 COUNTER=0
 # Obtain list of "Login Name","First Name","Last Name" only (to remove duplicates)
 cat $INPUT_FILE | sed -e "s/^\(.*\),.*,.*$/\1/" > $INPUT_FILE.dupl
 sort $INPUT_FILE.dupl | uniq > $INPUT_FILE.nodupl
 rm -f $INPUT_FILE.dupl
 # Process each line of file and create grouping
 for LINE in $(cat $INPUT_FILE.nodupl) ; do 
   LOGONNAME=`echo $LINE | sed -e 's/^"\([^"]*\)".*/\1/'`
   FIRSTNAME=`echo $LINE | sed -e 's/^"[^"]*","\([^"]*\)".*/\1/'`
   LASTNAME=`echo $LINE | sed -e 's/^"[^"]*","[^"]*","\([^"]*\)".*/\1/'`
   echo "\"$FIRSTNAME\" \"$LASTNAME\" \"0\"" >>$TEMPFILE
   echo "{" >>$TEMPFILE
   echo "  match logonname \"$LOGONNAME\"" >>$TEMPFILE
   echo "  match usertype \"$USER_TYPE\"" >>$TEMPFILE
   echo "}" >>$TEMPFILE
   ((COUNTER += 1))
 done
 rm -f $INPUT_FILE.nodupl
}

# Process Groups
function build_groups {
 INPUT_FILE=$1
 USER_TYPE=$2
 PROCESSED_GROUPS=""
 COUNTER=0
 # Process each line of file and create grouping
 for LINE in $(cat $INPUT_FILE) ; do 
   ROLE=`echo $LINE | sed -e 's/^"[^"]*","[^"]*","[^"]*","\([^"]*\)".*/\1/'`
   if [ "a$ROLE" = "a" ] ; then 
     continue
   fi
   ROLE_ALREADY_PROCESSED=`echo $PROCESSED_GROUPS | grep \"$ROLE\"`
   if [ ! "a$ROLE_ALREADY_PROCESSED" = "a" ] ; then 
     continue
   fi
   echo "\"$ROLE\"" >>$TEMPFILE
   ((COUNTER += 1))
   # here we will look for all users belongs to ROLE
   for LINE2 in $(cat $INPUT_FILE) ; do 
     ROLE_MATCHED=`echo $LINE2 | sed -e 's/^"[^"]*","[^"]*","[^"]*","\([^"]*\)".*/\1/'`
     LOGONNAME=`echo $LINE2 | sed -e 's/^"\([^"]*\)".*/\1/'`
     if [ "$ROLE_MATCHED" = "$ROLE" ] ; then
       echo "{" >>$TEMPFILE
       echo "  match logonname \"$LOGONNAME\"" >>$TEMPFILE
       echo "  match usertype \"$USER_TYPE\"" >>$TEMPFILE
       echo "}" >>$TEMPFILE
     fi
   done
   PROCESSED_GROUPS="$PROCESSED_GROUPS \"$ROLE\""
 done
}
##################### INTERNAL FUNCTIONS #######################

# Check last incoming parameter - propsfile name
eval PROPSFILE=\$$#
if [ "a$PROPSFILE" = "a" ] ; then 
 echo `date "+%a %D %T"` "ERROR: PROPS file is not defined. Exiting." > guardium_uis.err
 exit 1
fi
ACTUATOR_LOG=../log/${PROPSFILE}.log
> $ACTUATOR_LOG

printlog "IBM Guardium UIS collect started on `hostname` (`uname`)."
printlog "========================================================"
printlog "Checking incoming parameters."

# Check number of incoming parameters
if [ $# -ge 6 ]
then
  :
else
  printlog "ERROR: Insufficient number of arguments. Exiting."
  exit 1
fi

# Read incoming parameters
TEMPFILE=$1
GROUPFILE=$2            # not used during collect
LOCATION=$3
GUARDIUM_TEMPLATE=$4    # required parameter
DATABASE_TEMPLATE=$5    # optional parameter

# Check incoming parameters
if [ "a$TEMPFILE" = "a" ] ; then 
 printlog "ERROR: Temporary file is not defined!"
 exit 1
fi
if [ "a$LOCATION" = "a" ] ; then 
 printlog "ERROR: Log files location is not defined!"
 exit 1
fi
if [ "a$GUARDIUM_TEMPLATE" = "a" ] ; then 
 printlog "ERROR: Guardium filename template is not defined!"
 exit 1
fi
if [ "a$DATABASE_TEMPLATE" = "a" ] ; then 
 printlog "INFO: Database filename template is not defined."
fi

# Create chunk file
> $TEMPFILE
if [ $? -ne 0 ] ; then 
 printlog "ERROR: Could not create chunk."
 exit 1
fi

# Create temporary unprocessed UIS files from latest Guardium and Database files
printlog "Looking for the recent UIS data."
GUARDIUM_FILE=`ls -1t "${LOCATION}" 2>>"${ACTUATOR_LOG}" | grep "${GUARDIUM_TEMPLATE}" | head -1`
if [ "a$GUARDIUM_FILE" = "a" ] ; then 
 printlog "WARNING: No Guardium UIS file found matching template $GUARDIUM_TEMPLATE."
else
 printlog "Guardium UIS file found: $GUARDIUM_FILE"
fi

if [ "a$DATABASE_TEMPLATE" != "a" ] ; then 
  DATABASE_FILE=`ls -1t "${LOCATION}" 2>>"${ACTUATOR_LOG}" | grep "${DATABASE_TEMPLATE}" | head -1`
  if [ "a$DATABASE_FILE" = "a" ] ; then 
   printlog "WARNING: No Database UIS file found matching template $DATABASE_TEMPLATE."
  else
   printlog "Database UIS file found: $DATABASE_FILE"
  fi
fi

# Exit if no files found for both templates
if [ "a$DATABASE_FILE" = "a" ] && [ "a$GUARDIUM_FILE" = "a" ] ; then 
 printlog "No files to collect. Exiting. Please check Guardium configuration."
 printlog "========================================================"
 printlog "Collect result: SUCCESS"
 exit 0
fi

echo "[Persons]" > $TEMPFILE

# Remove header from the files and process users
if [ "a$GUARDIUM_FILE" != "a" ] ; then 
 printlog "Processing Guardium users."
 sed 1d "$LOCATION/$GUARDIUM_FILE" > $TEMPFILE.1 2>>$ACTUATOR_LOG
 build_users $TEMPFILE.1 "guardium"
 if [ $? -ne 0 ] ; then 
  printlog "ERROR: Could not process Guardium users."
  exit 1
 fi
 printlog "Found $COUNTER items."
fi
if [ "a$DATABASE_FILE" != "a" ] ; then 
 printlog "Processing Database users."
 sed 1d "$LOCATION/$DATABASE_FILE" > $TEMPFILE.2 2>>$ACTUATOR_LOG
 build_users $TEMPFILE.2 "database"
 if [ $? -ne 0 ] ; then 
  printlog "ERROR: Could not process Database users."
  exit 1
 fi
 printlog "Found $COUNTER items."
fi

# Process groups (roles)
echo "[SourceGroup]" >> $TEMPFILE
if [ "a$GUARDIUM_FILE" != "a" ] ; then 
 printlog "Processing Guardium groups."
 build_groups $TEMPFILE.1 "guardium"
 if [ $? -ne 0 ] ; then 
  printlog "ERROR: Could not process Guardium roles."
  exit 1
 fi
 printlog "Found $COUNTER items."
fi
if [ "a$DATABASE_FILE" != "a" ] ; then
 printlog "Processing Database groups."
 build_groups $TEMPFILE.2 "database"
 if [ $? -ne 0 ] ; then 
  printlog "ERROR: Could not process Database roles."
  exit 1
 fi
 printlog "Found $COUNTER items."
fi

# Finalize processing
rm -f $TEMPFILE.1
rm -f $TEMPFILE.2
printlog "========================================================"
printlog "Collect result: SUCCESS"
