@echo off

rem ----- Receive parameters from the TSIEM actuator
set TEMP_FILE1=%~1
set TEMP_FILE2=%~2
set RUNTIME_LOG_LOCATION=%3
set MGMT_LOG_LOCATION=%4
set JAVA_PATH=%~5
set LOG_TMPL=%~6

set TEMP_LOG="..\log\getitfimlogs.err"

for %%A in (%*) do set PROPS_FILE=%%A

if not exist ..\log mkdir ..\log

if %PROPS_FILE% EQU "" (
    echo [%date%][%time%] Failure: Missing argument PROPS_FILE >> %TEMP_LOG%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %TEMP_LOG%
    exit /b 1
)

rem ----- Set log file path
set LOG_FILE="..\log\%PROPS_FILE%.log"

rem ----- Check all parameters presence 

echo [%date%][%time%] Processing started ...> %LOG_FILE%

if %TEMP_FILE1% EQU "" (
    echo [%date%][%time%] Failure: Missing argument TEMP_FILE1. >> %LOG_FILE%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %LOG_FILE%
    exit /b 1
)

if %TEMP_FILE2% EQU "" (
    echo [%date%][%time%] Failure: Missing argument TEMP_FILE2. >> %LOG_FILE%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %LOG_FILE%
    exit /b 1
)

if %RUNTIME_LOG_LOCATION% EQU "" (
    echo [%date%][%time%] Warning: Missing runtime log location. >> %LOG_FILE%
)

if %MGMT_LOG_LOCATION% EQU "" (
    echo [%date%][%time%] Warning: Missing management log location. >> %LOG_FILE%
)

if not exist %MGMT_LOG_LOCATION% (
   if not exist %RUNTIME_LOG_LOCATION% (
    echo [%date%][%time%] Failure: Both runtime and management log locations are missing or incorrect.>> %LOG_FILE%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %LOG_FILE%
    exit /b 1
   )
)

if %LOG_TMPL% EQU "" (
    echo [%date%][%time%] Failure: Missing log name template. >> %LOG_FILE%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %LOG_FILE%
    exit /b 1
)

rem -- checking JAVA
set JAR_FILE=../bin/getitfimlogs.jar
set JAR_COMMON_FILE=../bin/escommon.jar
set JAVA_CLASS=com.ibm.tsiem.gensub.itfim.java.GetItfimLogs
set JAVA_EXE=java.exe

if "%JAVA_PATH%" == "" (
   echo "WARNING: JRE path is not specified in ES properties. Search for existing Java binaries" >> %LOG_FILE%
   for /F "tokens=2,3 delims=:" %%A in ('where.exe "%JAVA_EXE%" ^| findstr /N "%JAVA_EXE%" ^| findstr /R "^1:"') do set JAVA_PATH=%%A:%%B
) else (
   set JAVA_PATH=%JAVA_PATH%\%JAVA_EXE%
)

if not exist "%JAVA_PATH%" (
   echo "WARNING: '%JAVA_PATH%' Java binary file does not exist. Default Java binary will be used." >> %LOG_FILE%
   set JAVA_PATH=%JAVA_EXE%
)
echo "Use Java binary file '%JAVA_PATH%'" >> %LOG_FILE%

rem ----- Clean or create files
type nul > %TEMP_FILE1%
type nul > %TEMP_FILE2%

echo [%date%][%time%] Reading state information. >> %LOG_FILE%

rem ----- Define  timestamp for initial collect
for /F %%i in ('..\bin\date.exe -d "2 days ago"  +"%%Y-%%m-%%dT%%H:%%M:%%S"') do set RUNTIME_LAST=%%i.000Z
set RUNTIME_LAST_ID="firstcollect"
for /F %%i in ('..\bin\date.exe -d "2 days ago"  +"%%Y-%%m-%%dT%%H:%%M:%%S"') do set MGMT_LAST=%%i.000Z
set MGMT_LAST_ID="firstcollect"

rem ----- Get timestamp from props file
IF EXIST %PROPS_FILE% (
  for /F "tokens=1,2 delims==" %%i in ('findstr RUNTIME_LAST %PROPS_FILE%') do (set RUNTIME_LAST=%%j)
  for /F "tokens=1,2 delims==" %%i in ('findstr RUNTIME_ID %PROPS_FILE%') do (set RUNTIME_LAST_ID=%%j)
  for /F "tokens=1,2 delims==" %%i in ('findstr MGMT_LAST %PROPS_FILE%') do (set MGMT_LAST=%%j)
  for /F "tokens=1,2 delims==" %%i in ('findstr MGMT_ID %PROPS_FILE%') do (set MGMT_LAST_ID=%%j)
) ELSE (
  echo [%date%][%time%] This is the first collect. >> %LOG_FILE%
)

type nul > %PROPS_FILE%.tmp

echo [%date%][%time%] Start to process runtime logs. >> %LOG_FILE%

for /F %%i in ('dir %RUNTIME_LOG_LOCATION% /b /A-D /O-N ^| findstr /b /r ^%LOG_TMPL%') do (

  echo [%date%][%time%] "Process %RUNTIME_LOG_LOCATION%\%%i" >> %LOG_FILE%
  %JAVA_EXE% -Dfile.encoding=UTF-8 -classpath "%JAR_COMMON_FILE%;%JAR_FILE%" %JAVA_CLASS% -inputfile %RUNTIME_LOG_LOCATION%\%%i -outputfile %PROPS_FILE%data.tmp -timestamp %RUNTIME_LAST% -platformtype Windows -timestampglobalidfile %PROPS_FILE%.tmp -globalid %RUNTIME_LAST_ID% >> %LOG_FILE% 2>&1
  
  IF NOT ERRORLEVEL 4 (
    IF ERRORLEVEL 3 (
      IF EXIST %PROPS_FILE%data.tmp (
        copy /b "%TEMP_FILE1%" + "%PROPS_FILE%data.tmp" "%TEMP_FILE1%"
        del %PROPS_FILE%data.tmp      
        rem checking whether we need to update sections in the propsfile
        
          for /F "tokens=1,2 delims==" %%i in ('findstr timestamp %PROPS_FILE%.tmp') do (echo RUNTIME_LAST=%%j> %PROPS_FILE%.runtimelast)
          for /F "tokens=1,2 delims==" %%i in ('findstr globalId %PROPS_FILE%.tmp') do (echo RUNTIME_ID=%%j> %PROPS_FILE%.runtimeid)

      )
    ) ELSE (  
      IF ERRORLEVEL 2 (
        IF EXIST %RUNTIME_LOG_LOCATION%\%%i (      
          copy /b "%TEMP_FILE1%" + "%RUNTIME_LOG_LOCATION%\%%i" "%TEMP_FILE1%"
          rem checking whether we need to update sections in the propsfile
          
          for /F "tokens=1,2 delims==" %%i in ('findstr timestamp %PROPS_FILE%.tmp') do (echo RUNTIME_LAST=%%j> %PROPS_FILE%.runtimelast)
          for /F "tokens=1,2 delims==" %%i in ('findstr globalId %PROPS_FILE%.tmp') do (echo RUNTIME_ID=%%j> %PROPS_FILE%.runtimeid)
          
        )
      ) ELSE (
          IF ERRORLEVEL 1 (
            echo [%date%][%time%] Warning: Supplied parameters are incorrect. >> %LOG_FILE%
            echo "" > %PROPS_FILE%.runtimeerror
          )
        )
    )
  ) else (
          echo RUNTIME_LAST=%RUNTIME_LAST%> %PROPS_FILE%.runtimelast
          echo RUNTIME_ID=%RUNTIME_LAST_ID%> %PROPS_FILE%.runtimeid
         )
  
)

type nul > %PROPS_FILE%.tmp

echo [%date%][%time%] Start to process management logs. >> %LOG_FILE%

for /F %%i in ('dir %MGMT_LOG_LOCATION% /b /A-D /O-N ^| findstr /b /r ^%LOG_TMPL%') do (

  echo [%date%][%time%] "Process %MGMT_LOG_LOCATION%\%%i" >> %LOG_FILE%
  rem java -Dfile.encoding=UTF-8 -classpath ".;..\bin\getitfimlogs.jar"  nl.consul.cea.gensub.itspm.java.ParseFile %MGMT_LOG_LOCATION%\%%i %PROPS_FILE%data.tmp %MGMT_LAST% cbe Windows %PROPS_FILE%.tmp %MGMT_LAST_ID%
  
  %JAVA_EXE% -Dfile.encoding=UTF-8 -classpath "%JAR_COMMON_FILE%;%JAR_FILE%" %JAVA_CLASS% -inputfile %MGMT_LOG_LOCATION%\%%i -outputfile %PROPS_FILE%data.tmp -timestamp %MGMT_LAST% -platformtype Windows -timestampglobalidfile %PROPS_FILE%.tmp -globalid %MGMT_LAST_ID% >> %LOG_FILE% 2>&1
  
  IF NOT ERRORLEVEL 4 (
    IF errorlevel 3 (
      IF EXIST %PROPS_FILE%data.tmp (
        copy /b "%TEMP_FILE2%" + "%PROPS_FILE%data.tmp" "%TEMP_FILE2%"
        rem checking whether we need to update sections in the propsfile
        
        for /F "tokens=1,2 delims==" %%i in ('findstr timestamp %PROPS_FILE%.tmp') do (echo MGMT_LAST=%%j> %PROPS_FILE%.mgmtlast)
        for /F "tokens=1,2 delims==" %%i in ('findstr globalId %PROPS_FILE%.tmp') do (echo MGMT_ID=%%j> %PROPS_FILE%.mgmtid)

      

      )
    ) ELSE (  
      IF errorlevel 2 (
        IF EXIST %MGMT_LOG_LOCATION%\%%i (
          copy /b "%TEMP_FILE2%" + "%MGMT_LOG_LOCATION%\%%i" "%TEMP_FILE2%"
          rem checking whether we need to update sections in the propsfile
        
          for /F "tokens=1,2 delims==" %%i in ('findstr timestamp %PROPS_FILE%.tmp') do (echo MGMT_LAST=%%j> %PROPS_FILE%.mgmtlast)
          for /F "tokens=1,2 delims==" %%i in ('findstr globalId %PROPS_FILE%.tmp') do (echo MGMT_ID=%%j> %PROPS_FILE%.mgmtid)

        )
      ) ELSE (
        IF ERRORLEVEL 1 (
          echo [%date%][%time%] Warning: Supplied parameters are incorrect. >> %LOG_FILE%
          echo "" > %PROPS_FILE%.mgmterror
        )
      )
    )
  ) else (
          echo MGMT_LAST=%MGMT_LAST%> %PROPS_FILE%.mgmtlast
          echo MGMT_ID=%MGMT_LAST_ID%> %PROPS_FILE%.mgmtid
         )

)


del %PROPS_FILE%.tmp


echo [%date%][%time%] Collect of records finished. >> %LOG_FILE%

echo [%date%][%time%] Saving state information. >> %LOG_FILE%
type nul > %PROPS_FILE%

IF exist %PROPS_FILE%.runtimelast type %PROPS_FILE%.runtimelast >>%PROPS_FILE%
IF exist %PROPS_FILE%.runtimeid type %PROPS_FILE%.runtimeid >>%PROPS_FILE%
IF exist %PROPS_FILE%.mgmtlast type %PROPS_FILE%.mgmtlast >>%PROPS_FILE%
IF exist %PROPS_FILE%.mgmtid type %PROPS_FILE%.mgmtid >>%PROPS_FILE%

IF exist %PROPS_FILE%.mgmtlast del %PROPS_FILE%.mgmtlast
IF exist %PROPS_FILE%.mgmtid del %PROPS_FILE%.mgmtid
IF exist %PROPS_FILE%.runtimelast del %PROPS_FILE%.runtimelast
IF exist %PROPS_FILE%.runtimeid del %PROPS_FILE%.runtimeid
IF exist %PROPS_FILE%data.tmp del %PROPS_FILE%data.tmp

IF exist %PROPS_FILE%.mgmterror (
   IF exist %PROPS_FILE%.runtimeerror (
    echo [%date%][%time%] Both logs failed to collect.>> %LOG_FILE%
    echo [%date%][%time%] Processing finished. [FAILURE]>> %LOG_FILE%
    del %PROPS_FILE%.runtimeerror
    del %PROPS_FILE%.mgmterror
    exit /b 1
    )
)


IF exist %PROPS_FILE%.mgmterror del %PROPS_FILE%.mgmterror
IF exist %PROPS_FILE%.runtimeerror del %PROPS_FILE%.runtimeerror

:success
echo [%date%][%time%] Processing finished. [SUCCESS] >> %LOG_FILE%

exit /b 0