#!/bin/ksh
TEMP_FILE1=$1
LOG_LOCATION=$OPTION2
LOG_TMPL=$OPTION3
ARCH_LOCATION=$OPTION4
JAVA_PATH=$OPTION5
SAP_LOG_API_PATH=$OPTION6

# active log file
PROPS_NAME=`basename $PROPSFILE`
PROPS_NAME=${PROPS_NAME%.*} 
ES_LOG="../log/${PROPS_NAME}.log"; 
CHUNKS_DIR="/tmp/ES-${PROPS_NAME}"

print_message()
{
  echo "$(date "+[%Y-%m-%d %H:%M:%S]") ${1}." >> "${ES_LOG}"
}

failure()
{
  [ -z "${1}" ] || print_message "ERROR: ${1}"
  print_message "Processing finished [FAILURE]"
  exit ${2:-1}
}

>${ES_LOG} || failure "Unable to create collect logfile '${ES_LOG}'"

if [ ! -f "$PROPSFILE" ]; then
   failure "Properties file '${PROPSFILE}' does not exist"
fi

if [ -z "$LOG_LOCATION" ]; then
   failure "Missing log location argument"
fi
if [ ! -d $LOG_LOCATION ]; then
   failure "Log location argument '$LOG_LOCATION' does not exist"
fi

if [ -z "$LOG_TMPL" ]; then
   failure "Missing logfiles mask (main logfile name) argument"
fi 

if [ -z "$SAP_LOG_API_PATH" ]; then
   failure "Missing SAP NetWeaver logging API jar absolute path argument"
fi

if [ ! -f "$SAP_LOG_API_PATH" ]; then
   failure "Specified SAP NetWeaver logging API jar '$SAP_LOG_API_PATH' does not exist"
fi

if [ -z "$JAVA_PATH" ]; then
   print_message "WARNING: JRE path is not specified in ES properties. Search for existing Java binaries"
   JAVA_EXE=""
else
   JAVA_EXE="$JAVA_PATH/java"
   if [ -f "${JAVA_EXE}" -a -x "${JAVA_EXE}" ]; then
      :
   else
      print_message "WARNING: Specified JRE binary '${JAVA_EXE}' not found. Search for existing Java binaries"
      JAVA_EXE=""
   fi
fi
if [ -z "$JAVA_EXE" ]; then
   JAVA_EXE=`which java`
   if [ -f "${JAVA_EXE}" -a -x "${JAVA_EXE}" ]; then
      :
   else
      failure "Java binary file does not exist"
   fi
fi
print_message "Use Java binary file '${JAVA_EXE}'"

>$TEMP_FILE1 || failure "Unable to create temporary chunk '$TEMP_FILE1'"

chmod 0600 $TEMP_FILE1 || failure "Unable to set strict permissions for temporary chunk '$TEMP_FILE1'"

[ -d $CHUNKS_DIR ] && rm -fr $CHUNKS_DIR
mkdir $CHUNKS_DIR || failure "Unable to create temporary directory to copy SAP AS original logfiles"

chmod 0700 $CHUNKS_DIR || failure "Unable to set strict permissions for temporary directory '$CHUNKS_DIR'"

print_message "Processing started"
print_message "Execute java collect binary '../bin/getsapjslogs.jar'"

"${JAVA_EXE}" \
  -classpath "../bin/getsapjslogs.jar:$SAP_LOG_API_PATH:${CLASSPATH}" \
  nl.consul.cea.gensub.sapjs.java.GetSAPLogs \
  -logdir  "$LOG_LOCATION" \
  -archdir "$ARCH_LOCATION" \
  -logfile "$LOG_TMPL" \
  -chunk1  "$TEMP_FILE1" \
  -chunk2  "$CHUNKS_DIR" \
  -propsfile "$PROPSFILE" \
  >>${ES_LOG} 2>&1

if [ $? -eq 0 ]; then
   exit 0
else
   failure "Collect process failed"
fi
