#!/bin/ksh

TEMPFILE=$1
DBTYPE=$3
DBNAME=$4
DBSCHEMA=$5
PORT=$6
USERNAME=$7
PASSWORD=$8
PROPSFILE=`eval echo $"$#"`
ACTUATOR_LOG="../log/gettamessologs.err"

if [ "$PROPSFILE" = "" ];
then
  echo "[`date`] Propsfile type is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

ACTUATOR_LOG="../log/`basename $PROPSFILE`.log";

echo "[`date`] Processing started ..."> $ACTUATOR_LOG;

if [ "$TEMPFILE" = "" ];
then
  echo "[`date`] Temporary file location is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

DBHOST=`grep "SystemName" $PROPSFILE | awk -F= '{print $2}'`
DBHOST=`echo $DBHOST | sed 's/^ *//'`

if [ "$DBHOST" = "" ]; 
then
   echo "[`date`] Missing parameter SystemName from $PROPSFILE">>$ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">>$ACTUATOR_LOG;
   exit 1;
fi 

echo $DBHOST | grep [\!\?\*\,] > /dev/null
if [ $? -eq 0 ];
then
   echo "[`date`] Host contains illegal characters." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

if [ "$PORT" = "" ];
then
  echo "[`date`] Database port is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

echo $PORT | grep [a-zA-Z\!\?\*\:\.\,] > /dev/null
if [ $? -eq 0 ];
then
   echo "[`date`] Database port contains illegal characters." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

if [ "$DBNAME" = "" ];
then
  echo "[`date`] Database name is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi


if [ "$USERNAME" = "" ];
then
  echo "[`date`] User name is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

if [ "$PASSWORD" = "" ];
then
  echo "[`date`] Password is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

if [ "$DBSCHEMA" = "" ];
then
  echo "[`date`] Database schema is not specified.." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

DBTYPE_OK=0
if [ "$DBTYPE" = "DB2" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ "$DBTYPE" = "Oracle" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ "$DBTYPE" = "MS SQL" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ $DBTYPE_OK eq 0 ];
then
   echo "[`date`] Wrong database type is specified. Using DB2 by default." >> $ACTUATOR_LOG;
   DBTYPE="DB2"
fi

echo "[`date`] Checking Java binary availability." >> $ACTUATOR_LOG;
which java > /dev/null
if [ $? -eq 1 ];
then
   echo "[`date`] Java binary is not found." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

echo "SELECT attrValue, roleDescription from (SELECT MAX(roleID) as maxrole, attrValue from (SELECT attrValue, roleID from $DBSCHEMA.IMSIdentityRole inner join $DBSCHEMA.IMSIdentityUniqueAttribute on $DBSCHEMA.IMSIdentityRole.imsID = $DBSCHEMA.IMSIdentityUniqueAttribute.imsID where $DBSCHEMA.IMSIdentityUniqueAttribute.attrName='Enterprise Login') alias GROUP BY attrValue) alias, $DBSCHEMA.IMSRole where maxrole=roleID" > IMSRoles_$PROPSFILE.sql

java -Dfile.encoding=UTF-8 -classpath "$CLASSPATH:../bin/jdbc-genact.jar" eprise.audit.chunktool.generic.java.JdbcGenact -driver="$DBTYPE" -host="$DBHOST" -port="$PORT" -database="$DBNAME" -username="$USERNAME" -passwd="$PASSWORD" -props="$PROPSFILE" -outfilename="$PROPSFILE.db_groups" -sqlfilename="IMSRoles_$PROPSFILE.sql" -useheaderline=no  -separator=";" -eraseoutfile=yes 2>>$ACTUATOR_LOG 1>>$ACTUATOR_LOG

if [ $? -ne 0 ];
then
   echo "[`date`] Error quering database." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

if [ -r "$PROPSFILE.db_groups" ] ;
         then
             echo "[SourceGroup]" > $TEMPFILE
             # sed is used to convert windows-like line terminators to a unix-like
             IFS=';' 
             sed 's/\\/=replacement=/g; s/.$//g' $PROPSFILE.db_groups | \
             while read sqlfile group role trailer; do 
                echo "\"$role role\""
                echo "{" 
                echo "   match logonname \"${group}\"" 
                echo "}" 
             done | sed 's/=replacement=/\\/g' >> $TEMPFILE 
         fi

rm -f $PROPSFILE.db_groups IMSRoles_$PROPSFILE.sql $PROPSFILE.tmp

echo "[`date`] Processing finished. [SUCCESS]">>$ACTUATOR_LOG; 



