#!/bin/ksh
TEMP_FILE3=$TEMPFILE3
DBTYPE=$OPTION2
DBNAME=$OPTION3
DBSCHEMA=$OPTION4
PORT=$OPTION5
USERNAME=$OPTION6
PASSWORD=$OPTION7
PROPS_FILE=$PROPSFILE
ACTUATOR_LOG="../log/gettamessologs.err"

if [ "$PROPS_FILE" = "" ];
then
  echo "[`date`] Propsfile type is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

ACTUATOR_LOG="../log/`basename $PROPS_FILE`.log";

echo "[`date`] Processing started ...">> $ACTUATOR_LOG;

if [ "$TEMP_FILE3" = "" ];
then
  echo "[`date`] Temporary file 3 location is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

DBHOST=`grep "SystemName" $PROPS_FILE | awk -F= '{print $2}'`
DBHOST=`echo $DBHOST | sed 's/^ *//'`

if [ "$DBHOST" = "" ]; 
then
   echo "[`date`] Missing parameter SystemName from $PROPS_FILE">>$ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">>$ACTUATOR_LOG;
   exit 1;
fi 

echo $DBHOST | grep [\!\?\*\,] > /dev/null
if [ $? -eq 0 ];
then
   echo "[`date`] Host contains illegal characters." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

if [ "$PORT" = "" ];
then
  echo "[`date`] Database port is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

echo $PORT | grep [a-zA-Z\!\?\*\:\.\,] > /dev/null
if [ $? -eq 0 ];
then
   echo "[`date`] Database port contains illegal characters." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi

if [ "$DBNAME" = "" ];
then
  echo "[`date`] Database name is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

if [ "$USERNAME" = "" ];
then
  echo "[`date`] User name is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

if [ "$PASSWORD" = "" ];
then
  echo "[`date`] Password is not specified." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

if [ "$DBSCHEMA" = "" ];
then
  echo "[`date`] Database schema is not specified.." >> $ACTUATOR_LOG;
  echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
  exit 1;
fi

DBTYPE_OK=0
if [ "$DBTYPE" = "DB2" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ "$DBTYPE" = "Oracle" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ "$DBTYPE" = "MS SQL" ];
then
   echo "[`date`] Database type is $DBTYPE." >> $ACTUATOR_LOG;
   DBTYPE_OK=1
fi
if [ $DBTYPE_OK eq 0 ];
then
   echo "[`date`] Wrong database type is specified. Using DB2 by default." >> $ACTUATOR_LOG;
   DBTYPE="DB2"
fi

echo "[`date`] Checking Java binary availability." >> $ACTUATOR_LOG;
which java > /dev/null
if [ $? -eq 1 ];
then
   echo "[`date`] Java binary is not found." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 1;
fi
 
echo "SELECT * FROM $DBSCHEMA.IMSLOGUserService" > IMSLOGUserService_$PROPS_FILE.sql

echo "[`date`] Collecting IMSLOGUserService table." >> $ACTUATOR_LOG;
java -Dfile.encoding=UTF-8 -classpath "$CLASSPATH:../bin/jdbc-genact.jar" eprise.audit.chunktool.generic.java.JdbcGenact -driver="$DBTYPE" -host="$DBHOST" -port="$PORT" -database="$DBNAME" -username="$USERNAME" -passwd="$PASSWORD" -props="$PROPS_FILE" -outfilename="$TEMP_FILE3" -sqlfilename="IMSLOGUserService_$PROPS_FILE.sql" -useheaderline=yes -tdcolumn=logTime -separator=";" -eraseoutfile=yes 2>>$ACTUATOR_LOG 1>>$ACTUATOR_LOG
if [ $? -ne 0 ];
then
   echo "[`date`] Unable to collect from the database." >> $ACTUATOR_LOG;
   echo "[`date`] Processing finished [FAILURE].">> $ACTUATOR_LOG;
   exit 0;
fi

if [ ! -f $TEMP_FILE3 ] ; then
 touch $TEMP_FILE3
fi

rm -f IMSLOGUserServiceActivity_$PROPS_FILE.sql

echo "[`date`] Processing finished. [SUCCESS]">>$ACTUATOR_LOG; 



